##  Step 1: Starting SSO Authentication Setup
If you haven't configured an SSO connection for your workspace before, you first enable the SSO setup in the administration area. If you currently have a legacy SSO connection configured and want to migrate to the self-service SSO, the SSO setup should already be enabled and you can proceed with the next step to add a new IdP.
  1. In LeanIX, navigate to **Administration** > **Authentication and SSO**.
  2. Select one of the SSO authentication types.
  3. Click Save to proceed with setting up the SSO configuration.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9dd13da2aebb4c37ab151059f7dc46d8_HiRes.png)
After saving, you can see a new Identity Providers section for setting up IdPs.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9c2b24e70dd8410fa6aa1d24a8913caa_HiRes.png)
